==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggframeattachposition.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggframeattachposition.h"


#include "iviewmodule.h"

#include "iggframecurrentinstance.h"
#include "iggframeposition.h"
#include "iggwidgetkeybutton.h"


iggFrameAttachPosition::iggFrameAttachPosition(iggFramePosition *buddy, const iObjectKey &mkey, const iObjectKey &pkey, const iString &name, iggFrame *parent, bool spinbox) : iggFrame(parent,1)
{
	iString ws = "Attach ";
	if(!name.IsEmpty()) ws += name + " ";
	ws += "to";
	if(spinbox) ws += " marker#";

	this->AddLine(new iggFrameCurrentInstance(true,ws,"Marker",mkey,iViewModule::KeyMarkerMax(),this));

	ws = "Place ";
	if(!name.IsEmpty()) ws += name + " ";
	ws += "at picked position";

	this->AddLine(new iggWidgetKeyExecButton(ws,pkey,this));

	this->AddBuddy(buddy);  //  if the position changes, the attachment is broken
}

==> ifrit_3.1.5.orig.tar.gz: ifrit-3.1.5/shells/generic/iggframeattachposition.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggframeattachposition.h"


#include "iviewmodule.h"

#include "iggframecurrentinstance.h"
#include "iggwidgetkeybutton.h"


iggFrameAttachPosition::iggFrameAttachPosition(iggWidget *buddy, const iObjectKey &mkey, const iString &name, iggFrame *parent, bool spinbox) : iggFrame(parent,1)
{
	iString ws = "Attach ";
	if(!name.IsEmpty()) ws += name + " ";
	ws += "to";
	if(spinbox) ws += " marker#";

	this->AddLine(new iggFrameCurrentInstance(true,ws,"Marker",mkey,iViewModule::KeyMarkerMax(),this,spinbox));
	this->AddBuddy(buddy);  //  if the position changes, the attachment is broken
}
